Statistical moment
==================

.. currentmodule:: chaospy

First Order Moments
-------------------

.. autosummary::
   :toctree: ../../api

   E
   E_cond

Second Order Moments
--------------------

.. autosummary::
   :toctree: ../../api

   Std
   Var
   Cov

Higher Order Moments
--------------------

.. autosummary::
   :toctree: ../../api

   Skew
   Kurt

Correlation Functions
---------------------

.. autosummary::
   :toctree: ../../api

   Corr
   Acf
   Spearman
